@@ -214,7 +214,7 @@ class MembershipTypeForm(TendenciBaseForm):
                                                                     fields_pos_d=fields_pos_d)
 
     def clean(self):
-        cleaned_data = self.cleaned_data
+        cleaned_data = super(MembershipTypeForm, self).clean()
         # Make sure Expiretion Grace Period <= Renewal Period End
         expiration_grace_period = self.cleaned_data['expiration_grace_period']
         renewal_period_end = self.cleaned_data['renewal_period_end']
