@@ -1,10 +1,9 @@
-import commands
-from datetime import date, timedelta
+
+from datetime import timedelta
 from decimal import Decimal
 
-from django.core.management.base import BaseCommand, CommandError
+from django.core.management.base import BaseCommand
 from django.db.models import Sum
-from django.conf import settings
 
 from tendenci.apps.metrics.models import Metric
 
@@ -21,7 +20,6 @@ class Command(BaseCommand):
         if 'verbosity' in options:
             verbosity = int(options['verbosity'])
 
-
         metrics = Metric.objects.filter(invoices__isnull=True)
         for metric in metrics:
             metric.invoices = self.get_invoices(metric.create_dt).count()
@@ -29,10 +27,10 @@ class Command(BaseCommand):
             metric.invoice_totals = Decimal(self.get_invoice_totals(metric.create_dt))
 
             if verbosity >= 2:
-                print 'metric.create_dt', metric.create_dt
-                print 'metric.invoices', metric.invoices
-                print 'metric.positive_invoices', metric.positive_invoices
-                print 'metric.invoice_totals', metric.invoice_totals
+                print('metric.create_dt', metric.create_dt)
+                print('metric.invoices', metric.invoices)
+                print('metric.positive_invoices', metric.positive_invoices)
+                print('metric.invoice_totals', metric.invoice_totals)
 
             metric.save()
 
