@@ -169,6 +169,13 @@ def index(request, username='', template_name="profiles/index.html"):
 
     directories = set([m.directory for m in memberships.exclude(directory_id__isnull=True) if m.directory])
     corps_list = user_this.corpmembershiprep_set.all().values_list('corp_profile__id', 'corp_profile__name')
+    recurring_payments = user_this.recurring_payments.filter(status=True, status_detail='active')
+
+    # industry
+    if memberships and get_setting('module', 'users', 'showindustry'):
+        industries = list(memberships.exclude(industry=None).values_list('industry__industry_name', flat=True))
+    else:
+        industries = None
 
     return render_to_resp(request=request, template_name=template_name, context={
         'can_edit': can_edit,
@@ -180,6 +187,7 @@ def index(request, username='', template_name="profiles/index.html"):
         'additional_owners': additional_owners,
         'group_memberships': group_memberships,
         'memberships': memberships,
+        'industries': industries,
         'directories': directories,
         'corps_list': corps_list,
         'registrations': registrations,
@@ -188,6 +196,7 @@ def index(request, username='', template_name="profiles/index.html"):
         'membership_reminders': membership_reminders,
         'can_auto_renew': can_auto_renew,
         'auto_renew_is_set': auto_renew_is_set,
+        'recurring_payments': recurring_payments
         })
 
 
@@ -246,6 +255,7 @@ def search(request, memberships_search=False, template_name="profiles/search.htm
         mts = None
 
     show_member_option = mts
+    show_industry = get_setting('module', 'users', 'showindustry')
 
     form = ProfileSearchForm(request.GET, mts=mts, user=request.user)
     if form.is_valid():
@@ -260,6 +270,9 @@ def search(request, memberships_search=False, template_name="profiles/search.htm
         group = form.cleaned_data.get('group', False)
         if group:
             group = int(group)
+        industry = form.cleaned_data.get('industry', False)
+        if industry:
+            industry = int(industry)
     else:
         first_name = None
         last_name = None
@@ -270,6 +283,7 @@ def search(request, memberships_search=False, template_name="profiles/search.htm
         membership_type = None
         member_only = False
         group = False
+        industry = False
 
     profiles = Profile.objects.filter(Q(status=True))
     if memberships_search:
@@ -353,6 +367,10 @@ def search(request, memberships_search=False, template_name="profiles/search.htm
         profiles = profiles.filter(user__membershipdefault__status_detail='active',
             user__membershipdefault__membership_type_id=membership_type)
 
+    if industry:
+        profiles = profiles.filter(user__membershipdefault__status_detail='active',
+            user__membershipdefault__industry_id=industry)
+
     profiles = profiles.order_by('user__last_name', 'user__first_name')
     base_template = 'profiles/base-wide.html'
     if memberships_search:
@@ -365,6 +383,7 @@ def search(request, memberships_search=False, template_name="profiles/search.htm
             'user_this': None,
             'search_form': form,
             'show_member_option': show_member_option,
+            'show_industry': show_industry,
             'memberships_search': memberships_search,
             'base_template': base_template})
 
@@ -650,6 +669,14 @@ def _get_next(request):
 def password_change(request, id, template_name='registration/custom_password_change_form.html',
                     post_change_redirect=None, password_change_form=ValidatingPasswordChangeForm):
     user_edit = get_object_or_404(User, pk=id)
+    try:
+        profile = user_edit.profile
+    except Profile.DoesNotExist:
+        profile = Profile.objects.create_profile(user=user_edit)
+
+    if not profile.allow_edit_by(request.user):
+        raise Http403
+
     if post_change_redirect is None:
         post_change_redirect = reverse('profile', kwargs={'username': user_edit.username})
     if request.method == "POST":
